==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit4/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/Address.java <==
package com.example.model;

/**
 * Model for Address
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.328Z")
@io.swagger.annotations.ApiModel(value = "Address", description = "Model for Address")
@javax.xml.bind.annotation.XmlRootElement(name = "Address")
public class Address implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String city = null;
	private java.lang.String country = null;
	private java.lang.String fullAddress = null;
	private java.lang.String postCode = null;
	private java.lang.String state = null;
	private java.lang.String streetAddress = null;
	private java.lang.String streetAddress2 = null;
	private java.lang.String suburb = null;
	
	/**
	 */
	public Address city(java.lang.String city) {
		setCity(city);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("city")
	@javax.validation.constraints.NotNull
	public java.lang.String getCity() {
		return this.city;
	}
	public void setCity(java.lang.String city) {
		this.city = city;
	}
	
	/**
	 */
	public Address country(java.lang.String country) {
		setCountry(country);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("country")
	public java.lang.String getCountry() {
		return this.country;
	}
	public void setCountry(java.lang.String country) {
		this.country = country;
	}
	
	/**
	 */
	public Address fullAddress(java.lang.String fullAddress) {
		setFullAddress(fullAddress);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("full_address")
	public java.lang.String getFullAddress() {
		return this.fullAddress;
	}
	public void setFullAddress(java.lang.String fullAddress) {
		this.fullAddress = fullAddress;
	}
	
	/**
	 */
	public Address postCode(java.lang.String postCode) {
		setPostCode(postCode);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("post_code")
	public java.lang.String getPostCode() {
		return this.postCode;
	}
	public void setPostCode(java.lang.String postCode) {
		this.postCode = postCode;
	}
	
	/**
	 */
	public Address state(java.lang.String state) {
		setState(state);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("state")
	public java.lang.String getState() {
		return this.state;
	}
	public void setState(java.lang.String state) {
		this.state = state;
	}
	
	/**
	 */
	public Address streetAddress(java.lang.String streetAddress) {
		setStreetAddress(streetAddress);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("street_address")
	public java.lang.String getStreetAddress() {
		return this.streetAddress;
	}
	public void setStreetAddress(java.lang.String streetAddress) {
		this.streetAddress = streetAddress;
	}
	
	/**
	 */
	public Address streetAddress2(java.lang.String streetAddress2) {
		setStreetAddress2(streetAddress2);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("street_address_2")
	public java.lang.String getStreetAddress2() {
		return this.streetAddress2;
	}
	public void setStreetAddress2(java.lang.String streetAddress2) {
		this.streetAddress2 = streetAddress2;
	}
	
	/**
	 */
	public Address suburb(java.lang.String suburb) {
		setSuburb(suburb);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("suburb")
	public java.lang.String getSuburb() {
		return this.suburb;
	}
	public void setSuburb(java.lang.String suburb) {
		this.suburb = suburb;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		Address address = (Address) o;
		return java.util.Objects.equals(this.city, address.city)
				&& java.util.Objects.equals(this.country, address.country)
				&& java.util.Objects.equals(this.fullAddress, address.fullAddress)
				&& java.util.Objects.equals(this.postCode, address.postCode)
				&& java.util.Objects.equals(this.state, address.state)
				&& java.util.Objects.equals(this.streetAddress, address.streetAddress)
				&& java.util.Objects.equals(this.streetAddress2, address.streetAddress2)
				&& java.util.Objects.equals(this.suburb, address.suburb);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.city, this.country, this.fullAddress, this.postCode, this.state, this.streetAddress, this.streetAddress2, this.suburb);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class Address {\n");
		
		sb.append("    city: ").append(toIndentedString(this.city)).append("\n");
		sb.append("    country: ").append(toIndentedString(this.country)).append("\n");
		sb.append("    fullAddress: ").append(toIndentedString(this.fullAddress)).append("\n");
		sb.append("    postCode: ").append(toIndentedString(this.postCode)).append("\n");
		sb.append("    state: ").append(toIndentedString(this.state)).append("\n");
		sb.append("    streetAddress: ").append(toIndentedString(this.streetAddress)).append("\n");
		sb.append("    streetAddress2: ").append(toIndentedString(this.streetAddress2)).append("\n");
		sb.append("    suburb: ").append(toIndentedString(this.suburb)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit4/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/Address.java <==
package com.example.model;

/**
 * Model for Address
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.431Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "Address", description = "Model for Address")
@javax.xml.bind.annotation.XmlRootElement(name = "Address")
public class Address implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String city = null;
	private java.lang.String country = null;
	private java.lang.String fullAddress = null;
	private java.lang.String postCode = null;
	private java.lang.String state = null;
	private java.lang.String streetAddress = null;
	private java.lang.String streetAddress2 = null;
	private java.lang.String suburb = null;
	
	/**
	 */
	public Address city(java.lang.String city) {
		setCity(city);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "city")
	@com.fasterxml.jackson.annotation.JsonProperty("city")
	@javax.validation.constraints.NotNull
	public java.lang.String getCity() {
		return this.city;
	}
	public void setCity(java.lang.String city) {
		this.city = city;
	}
	
	/**
	 */
	public Address country(java.lang.String country) {
		setCountry(country);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "country")
	@com.fasterxml.jackson.annotation.JsonProperty("country")
	public java.lang.String getCountry() {
		return this.country;
	}
	public void setCountry(java.lang.String country) {
		this.country = country;
	}
	
	/**
	 */
	public Address fullAddress(java.lang.String fullAddress) {
		setFullAddress(fullAddress);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "full_address")
	@com.fasterxml.jackson.annotation.JsonProperty("full_address")
	public java.lang.String getFullAddress() {
		return this.fullAddress;
	}
	public void setFullAddress(java.lang.String fullAddress) {
		this.fullAddress = fullAddress;
	}
	
	/**
	 */
	public Address postCode(java.lang.String postCode) {
		setPostCode(postCode);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "post_code")
	@com.fasterxml.jackson.annotation.JsonProperty("post_code")
	public java.lang.String getPostCode() {
		return this.postCode;
	}
	public void setPostCode(java.lang.String postCode) {
		this.postCode = postCode;
	}
	
	/**
	 */
	public Address state(java.lang.String state) {
		setState(state);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "state")
	@com.fasterxml.jackson.annotation.JsonProperty("state")
	public java.lang.String getState() {
		return this.state;
	}
	public void setState(java.lang.String state) {
		this.state = state;
	}
	
	/**
	 */
	public Address streetAddress(java.lang.String streetAddress) {
		setStreetAddress(streetAddress);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "street_address")
	@com.fasterxml.jackson.annotation.JsonProperty("street_address")
	public java.lang.String getStreetAddress() {
		return this.streetAddress;
	}
	public void setStreetAddress(java.lang.String streetAddress) {
		this.streetAddress = streetAddress;
	}
	
	/**
	 */
	public Address streetAddress2(java.lang.String streetAddress2) {
		setStreetAddress2(streetAddress2);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "street_address_2")
	@com.fasterxml.jackson.annotation.JsonProperty("street_address_2")
	public java.lang.String getStreetAddress2() {
		return this.streetAddress2;
	}
	public void setStreetAddress2(java.lang.String streetAddress2) {
		this.streetAddress2 = streetAddress2;
	}
	
	/**
	 */
	public Address suburb(java.lang.String suburb) {
		setSuburb(suburb);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "suburb")
	@com.fasterxml.jackson.annotation.JsonProperty("suburb")
	public java.lang.String getSuburb() {
		return this.suburb;
	}
	public void setSuburb(java.lang.String suburb) {
		this.suburb = suburb;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		Address address = (Address) o;
		return java.util.Objects.equals(this.city, address.city)
				&& java.util.Objects.equals(this.country, address.country)
				&& java.util.Objects.equals(this.fullAddress, address.fullAddress)
				&& java.util.Objects.equals(this.postCode, address.postCode)
				&& java.util.Objects.equals(this.state, address.state)
				&& java.util.Objects.equals(this.streetAddress, address.streetAddress)
				&& java.util.Objects.equals(this.streetAddress2, address.streetAddress2)
				&& java.util.Objects.equals(this.suburb, address.suburb);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.city, this.country, this.fullAddress, this.postCode, this.state, this.streetAddress, this.streetAddress2, this.suburb);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class Address {\n");
		
		sb.append("    city: ").append(toIndentedString(this.city)).append("\n");
		sb.append("    country: ").append(toIndentedString(this.country)).append("\n");
		sb.append("    fullAddress: ").append(toIndentedString(this.fullAddress)).append("\n");
		sb.append("    postCode: ").append(toIndentedString(this.postCode)).append("\n");
		sb.append("    state: ").append(toIndentedString(this.state)).append("\n");
		sb.append("    streetAddress: ").append(toIndentedString(this.streetAddress)).append("\n");
		sb.append("    streetAddress2: ").append(toIndentedString(this.streetAddress2)).append("\n");
		sb.append("    suburb: ").append(toIndentedString(this.suburb)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
